@@ -38,22 +38,15 @@ class Device(threading.Thread):
 
     Attributes
     ----------
-    device_type (str) :
+    device_type : str
         The type of device (e.g. TempSensor, GPS...).
-    device_id (str) :
+    device_id : str
         A unique identifier for this device
-    device_name (str) :
+    device_name : str
         The name for this device (E.g. GlassHouse, MothersZimmerFrame...)
 
     Methods
     -------
-    send(header, body) :
-        Send an alarm with a header and body.
-
-    send_alarm(alarm_id, message_header, message_body) :
-        Sends and alarm notification to DashIO apps registered on the DashIO server.
-        Notifications are only sent if the device is connected to the DashIO server with a DashConnection.
-
     add_control(iot_control) :
         Add a control to the device.
 
@@ -81,7 +74,7 @@ class Device(threading.Thread):
     unset_tcp_callback() :
         Clears the set TCP callback.
 
-    set_mqtt_callback(callback)
+    set_mqtt_callback(callback) :
         Set a callback function that is called when the DashIO app provides MQTT provisioning information.
 
     unset_mqtt_callback() :
@@ -171,18 +164,7 @@ class Device(threading.Thread):
         reply += dvvw_str
         return reply
 
-    def send_alarm(self, alarm_id, message_header, message_body):
-        """Send an Alarm to the Dash server.
-
-        Parameters
-        ----------
-        alarm_id : str
-            An identifier used by iotdashboard to manage the alarm. It should be unique for each connection.
-        message_header : str
-            Title for the Alarm.
-        message_body : str
-            The text body of the Alarm.
-        """
+    def _send_alarm(self, alarm_id, message_header, message_body):
         payload = self._device_id_str + f"\t{alarm_id}\t{message_header}\t{message_body}\n"
         logging.debug("ALARM: %s", payload)
         self.tx_zmq_pub.send_multipart([b"ALARM", b'0', payload.encode('utf-8')])
@@ -212,7 +194,7 @@ class Device(threading.Thread):
             self._cfg["numDeviceViews"] += 1
         try:
             if isinstance(iot_control, Alarm):
-                iot_control.message_tx_event += self.send_alarm
+                iot_control.message_tx_event += self._send_alarm
             else:
                 iot_control.message_tx_event += self._send_data
         except AttributeError:
@@ -370,6 +352,7 @@ class Device(threading.Thread):
                  device_type: str,
                  device_id: str,
                  device_name: str,
+                 cfg_dict: dict = None,
                  context=None) -> None:
         """DashDevice
 
@@ -381,6 +364,8 @@ class Device(threading.Thread):
                 A unique identifier for this device
             device_name : str
                 The name for this device
+            cfg_dict : dict optional
+                Setup dict to cfgRev, defaults None
             context : optional
                 ZMQ context. Defaults to None.
         """
@@ -406,12 +391,14 @@ class Device(threading.Thread):
         self._control_dict = {}
         self._cfg = {}
         self._device_id_str = f"\t{device_id}"
+        if cfg_dict is not None:
+            self._cfg["cfgRev"] = cfg_dict['CFG']['cfgRev']
         self._cfg["numDeviceViews"] = 0
         self.running = True
         self.start()
 
     def use_cfg64(self):
-        """Generate CFG64 formated CFG messages
+        """Generate a CFG64 formated CFG message
         """
         self._device_commands_dict['CFG'] = self._make_cfg64
 
@@ -467,7 +454,7 @@ class Device(threading.Thread):
         self._send_data(f"\t{{device_id}}\tNAME\t{self._device_name}\t")
 
     def close(self):
-        """Close the connection"""
+        """Close the device"""
         self.running = False
 
     def run(self):
