@@ -151,7 +151,7 @@ class Control:
             num_columns = int(data[3])
             dashboard_id = data[2]
         except (IndexError, ValueError):
-            return
+            return ""
         if self._control_position_column_3 and num_columns == 3:
             self._cfg["xPositionRatio"] = self._control_position_column_3.x_position_ratio
             self._cfg["yPositionRatio"] = self._control_position_column_3.y_position_ratio
